<?php
	/*
	 * FeedImport: Importiere RSS 2.0-Feeds und gib die Inhalte aus
	 * Quelle: http:/www-coding.de/rss-feed-import-mit-php/
	 * (hier findest du auch Beispiele und Erläuterungen)
	 *
	 * BEISPIEL
	 * siehe rss_example.php
	 */

	class RSSImport {
		private $feedInfo = array(), $feedItems = array();
	
		// Konstruktor: Verarbeitung des Feeds aus $feedUrl //
		public function __construct($feedUrl) {
			$xml = simplexml_load_file($feedUrl, 'SimpleXMLElement', LIBXML_NOCDATA);
			
			if (!$xml) {
				// Fehler: Es handelt es sich um kein gültiges XML-Dokument //
				return false;
			} else {
				// Feed-Informationen speichern //
				$this -> feedInfo['title'] = $xml -> channel -> title[0];
				$this -> feedInfo['link'] = $xml -> channel -> link[0];
					
				if (isset($xml -> channel -> description))
					$this -> feedInfo['description'] = $xml -> channel -> description[0];
						
				if (isset($xml -> channel -> lastBuildDate))
					$this -> feedInfo['updated'] = $xml -> channel -> lastBuildDate[0];
						
				// Einträge speichern //
				$this -> saveItems($xml);
			}
		}
		
		// Liefert die Feed-Informationen für ein Element, z.B. 'title' oder für alle (false) aus //
		public function getFeedInfo($element=false) {
			if ($element && isset($this -> feedInfo[$element])) {
				// Einzelnes Element zurückgeben //
				return $this -> feedInfo[$element];
			} else if (!$element) {
				// Komplettes Array zurückgeben //
				return $this -> feedInfo;
			}
			
			// Keine Ausgabe -> Fehler //
			return false;
		}
		
		// Liefert die Informationen als Array für einen Eintrag mit der ID $id oder für alle (false) //
		public function getItems($id=false) {
			if ($id && isset($this -> feedItems)) {
				// Informationen für einen Eintrag //
				return $this -> feedItems[$id];
			} else if (!$id) {
				// Informationen für alle Einträge //
				return $this -> feedItems;
			}
			
			// Keine Ausgabe -> Fehler //
			return false;
		}
		
		// Speichern der einzelnen RSS-Einträge in $this -> feedItems //
		private function saveItems($xml) {
			foreach ($xml -> channel -> item AS $item) {
				// Zeit in einen Timestamp umwandeln //
				$itemDate = DateTime :: createFromFormat('D, d M Y H:i:s O', $item -> pubDate);
							
				$this -> feedItems[] = array(
												'title' 	=> $item -> title,
												'link' 		=> $item -> link,
												'published'	=> $itemDate -> format('U'),
												'content'	=> $item -> description
											);
			}
		}
	}
?>
